@@ -7,7 +7,7 @@ Created on 2015-7-23
 
 from PyFin.Math import Accumulators
 from PyFin.Math import Distributions
-from PyFin.Math.MathConstants import MathConstants
+from PyFin.Math import MathConstants
 
 __all__ = ['Accumulators',
            'Distributions',
